  /*  powershell.h - powershell
   *  Copyright (C) 1999  Matt Spong <spong@glue.umd.edu>
   *  Based from zterm.c by Michael Zucci from the libzvt docs
   *
   *  A big, puffy lotsa-shells-in-one app. 
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License
   *  along with this program; if not, write to the Free Software
   *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
   */

#include <stdio.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <errno.h>
#include <string.h>
#include <pwd.h>
#include <stdlib.h>
#include <assert.h>

#include <gtk/gtk.h>
#include <gdk/gdkx.h>
#include <gdk/gdkprivate.h>
#include <gdk/gdkkeysyms.h>

#include <zvt/zvtterm.h>

#include "config.h"

char FONT[512];
int scrollbacklines;

#define login_shell 0

/* structures */
typedef struct _appentry
{
  char * tab_title;
  char * command;
  char * menu_item_title;

  char * menu_title;
  char ** menu_entries;

  GtkWidget * menubar;

} appentry;

typedef struct _preferences
{
  char http_handler[256], ftp_handler[256], 
    mail_handler[256], telnet_handler[256];

  int use_pixmap, transparent, shaded;
  char bg_pixmap[512];

  char font[512];

  int colors[16][16][16];

  int scrollbacklines;

} preferences;


/* globals */
extern char      **environ;       
extern char **env;
extern char **env_copy;
extern int winid_pos;
extern GtkWidget * window;
extern GtkWidget * notebook;
extern appentry * app_entries;
extern int num_apps;
extern int terms_open;
extern preferences Prefs;
extern ZvtTerm * current_term;

extern GtkItemFactoryEntry * menu_items;


/* signal handlers */
void child_died_event (ZvtTerm *term);
void term_died_event (ZvtTerm *term);
void quit_proggie (GtkWidget * widget, GdkEvent * event, gpointer data);
void title_changed_event (ZvtTerm *term, VTTITLE_TYPE type, 
				 char *newtitle);
void set_hints (GtkWidget *widget);

gboolean term_key_event (GtkWidget * widget, GdkEventKey * event, gpointer user_data);

void NotebookHandler (GtkNotebook * notebook, GtkNotebookPage * page,
		      gint page_num, gpointer user_data);
void MenuHandler (GtkWidget * w, gchar * data);

gint term_click_event (GtkWidget * widget, GdkEventButton * event);

void  
drag_data_received  (GtkWidget *widget, GdkDragContext *context, 
                     gint x, gint y,
                     GtkSelectionData *selection_data, guint info,
                     guint time);

/* program functions */

GtkWidget * new_term (GtkWidget * notebook, gchar * command, gchar * args,
		      gchar * title);
void get_main_menu (GtkWidget * window, GtkWidget **menubar);
int InitMenus (GtkWidget * window);
int InitRCFile ();
int WriteRCFile ();
int DoPreferences();
void RenameTerm();
void RenameTerm2();
void AboutDialog();
void FileRun();
void FontSel();
void UpdateTerm(ZvtTerm * term);
void UpdateAllTerms();
ZvtTerm * get_nth_zvt (GtkNotebook * notebook, gint n);
void QuickMessage (gchar * message);
